==> 5.8.0.tar.gz: ciphey/translations/pt-br/CODE_OF_CONDUCT.md <==
# Código de conduta do colaborador

## Nosso juramento

No interesse de promover um ambiente aberto e acolhedor, nós como contribuidores e mantedores juramos fazer com que a participação no nosso projeto e comunidade, uma experiência livre de assédio para todos, independente de idade, tamanho do corpo, deficiência, etnia, características sexuais, identidade de gênero e expressão, nível de experiência, educação, status sócio-econômico, nacionalidade, aparência pessoal, raça, religião ou identidade e orientação sexual.

## Nossas normas

Exemplos de comportamentos que contribuem em criar um ambiente positivo incluem:
* Usar linguagem acolhedora e inclusiva
* Respeitar diferentes pontos de vista e experiências
* Aceitar críticas construtivas
* Focar no que é melhor para a comunidade
* Demonstrar empatia para os outros membros da comunidade

Exemplos de comportamentos inaceitáveis por participantes incluem:
* Uso de linguagem ou imagens sexuais e avanços ou atenções sexuais indesejáveis.
* Comentários indesejáveis, insultantes/derrogatórios e ataques pessoais ou políticos.
* Abuso público ou privado
* Publicar informação privada de alguem, como endereço fisíco ou virtual, sem permissão explícita.
* Outras condutas que poderiam ser consideradas inapropriadas num ambiente profissional

## Nossas Responsabilidades

Mantedores do projeto são responsáveis por clarificar as normas de comportamento aceitável e é esperado que tomem ações corretivas apropriadas e justas em resposta a qualquer instância de comportamento inaceitável.

São responsabilidades e direitos dos mantedores do projeto:remover, editar ou rejeitar comentários, commits, códifo, edições na wiki, questões e outras contribuições que não se alinhem com esse código de conduta, ou banir temporáriamente ou permanentemente qualquer contribuidor por outro comportamento que são dados como inapropriados, ameaçadores, ofensivos ou prejudiciais.

## Escopo

Esse código de conduta aplica tanto em espaços para o projeto como em espaços públicos em quem um indivíduo esteja representando o projeto ou a comunidade. Exemplos de representação do projeto ou comunidade incluem usar um endereço de e-mail oficial do projeto, publicações numa conta oficial do projeto em uma rede social ouo agindo como um representante num evento online ou offline. Representação do projeto pode ser definido e clarificado posteriormente por mantedores do projeto.

## Execução

Instâncias de comportamento abusivo, assediante ou inaceitável poderá ser reportado contactando o time do projeto em brandon_skerrit. Todas reclamações serão revisadas e investigadas e resultarão em uma resposta que seja decidida necessária e apropriada para as circunstâncias. O time do projeto é obrigado a manter confidencialidade em relação ao relator de um incidente. Mais detalhes da política de execução específica podem ser publicados separadamente. 

Mantedores do projeto que não seguirem ou executarem o códico de conduta em boa fé podem sofrer repercussões temporárias ou permanentes como determinado por outros membros da liderança do projeto.

## Atribuição

Esse código de conduta é adaptado do [Contributor Covenant][homepage], versão 1.4,
disponível em https://www.contributor-covenant.org/version/1/4/code-of-conduct.html

[homepage]: https://www.contributor-covenant.org

Para respostas de perguntas comuns sobre esse código de conduta, veja
https://www.contributor-covenant.org/faq

==> 5.10.0.tar.gz: ciphey/translations/pt-br/CODE_OF_CONDUCT.md <==
# Código de conduta do colaborador

## Nosso juramento

No interesse de promover um ambiente aberto e acolhedor, nós como contribuidores e mantedores juramos fazer com que a participação no nosso projeto e comunidade, uma experiência livre de assédio para todos, independente de idade, tamanho do corpo, deficiência, etnia, características sexuais, identidade de gênero e expressão, nível de experiência, educação, status sócio-econômico, nacionalidade, aparência pessoal, raça, religião ou identidade e orientação sexual.

## Nossas normas

Exemplos de comportamentos que contribuem em criar um ambiente positivo incluem:

- Usar linguagem acolhedora e inclusiva
- Respeitar diferentes pontos de vista e experiências
- Aceitar críticas construtivas
- Focar no que é melhor para a comunidade
- Demonstrar empatia para os outros membros da comunidade

Exemplos de comportamentos inaceitáveis por participantes incluem:

- Uso de linguagem ou imagens sexuais e avanços ou atenções sexuais indesejáveis.
- Comentários indesejáveis, insultantes/derrogatórios e ataques pessoais ou políticos.
- Abuso público ou privado
- Publicar informação privada de alguem, como endereço fisíco ou virtual, sem permissão explícita.
- Outras condutas que poderiam ser consideradas inapropriadas num ambiente profissional

## Nossas Responsabilidades

Mantedores do projeto são responsáveis por clarificar as normas de comportamento aceitável e é esperado que tomem ações corretivas apropriadas e justas em resposta a qualquer instância de comportamento inaceitável.

São responsabilidades e direitos dos mantedores do projeto:remover, editar ou rejeitar comentários, commits, códifo, edições na wiki, questões e outras contribuições que não se alinhem com esse código de conduta, ou banir temporáriamente ou permanentemente qualquer contribuidor por outro comportamento que são dados como inapropriados, ameaçadores, ofensivos ou prejudiciais.

## Escopo

Esse código de conduta aplica tanto em espaços para o projeto como em espaços públicos em quem um indivíduo esteja representando o projeto ou a comunidade. Exemplos de representação do projeto ou comunidade incluem usar um endereço de e-mail oficial do projeto, publicações numa conta oficial do projeto em uma rede social ouo agindo como um representante num evento online ou offline. Representação do projeto pode ser definido e clarificado posteriormente por mantedores do projeto.

## Execução

Instâncias de comportamento abusivo, assediante ou inaceitável poderá ser reportado contactando o time do projeto em brandon_skerrit. Todas reclamações serão revisadas e investigadas e resultarão em uma resposta que seja decidida necessária e apropriada para as circunstâncias. O time do projeto é obrigado a manter confidencialidade em relação ao relator de um incidente. Mais detalhes da política de execução específica podem ser publicados separadamente.

Mantedores do projeto que não seguirem ou executarem o códico de conduta em boa fé podem sofrer repercussões temporárias ou permanentes como determinado por outros membros da liderança do projeto.

## Atribuição

Esse código de conduta é adaptado do [Contributor Covenant][homepage], versão 1.4,
disponível em <https://www.contributor-covenant.org/version/1/4/code-of-conduct.html>

[homepage]: https://www.contributor-covenant.org

Para respostas de perguntas comuns sobre esse código de conduta, veja
<https://www.contributor-covenant.org/faq>
